@@ -18,7 +18,7 @@ int32_t SPVM__Sys__User__getuid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getuid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getuid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t uid = getuid();
@@ -34,7 +34,7 @@ int32_t SPVM__Sys__User__geteuid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "geteuid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "geteuid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t euid = geteuid();
@@ -50,7 +50,7 @@ int32_t SPVM__Sys__User__getgid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getgid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getgid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t gid = getgid();
@@ -66,7 +66,7 @@ int32_t SPVM__Sys__User__getegid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getegid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getegid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t egid = getegid();
@@ -82,7 +82,7 @@ int32_t SPVM__Sys__User__setuid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "setuid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "setuid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t uid = stack[0].ival;
@@ -104,7 +104,7 @@ int32_t SPVM__Sys__User__seteuid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "seteuid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "seteuid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t euid = stack[0].ival;
@@ -126,7 +126,7 @@ int32_t SPVM__Sys__User__setgid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "setgid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "setgid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t gid = stack[0].ival;
@@ -148,7 +148,7 @@ int32_t SPVM__Sys__User__setegid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "setegid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "setegid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t egid = stack[0].ival;
@@ -170,7 +170,7 @@ int32_t SPVM__Sys__User__setpwent(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
 
 #ifdef _WIN32
-  env->die(env, stack, "setpwent is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "setpwent is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   setpwent();
@@ -185,7 +185,7 @@ int32_t SPVM__Sys__User__endpwent(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "endpwent is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "endpwent is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   endpwent();
@@ -199,7 +199,7 @@ int32_t SPVM__Sys__User__getpwent(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getpwent is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getpwent is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t e = 0;
@@ -230,7 +230,7 @@ int32_t SPVM__Sys__User__setgrent(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "setgrent is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "setgrent is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   setgrent();
@@ -244,7 +244,7 @@ int32_t SPVM__Sys__User__endgrent(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "endgrent is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "endgrent is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   endgrent();
@@ -258,7 +258,7 @@ int32_t SPVM__Sys__User__getgrent(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getgrent is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getgrent is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t e = 0;
@@ -289,7 +289,7 @@ int32_t SPVM__Sys__User__getgroups(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getgroups is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getgroups is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -321,7 +321,7 @@ int32_t SPVM__Sys__User__setgroups(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "setgroups is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "setgroups is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   
@@ -352,7 +352,7 @@ int32_t SPVM__Sys__User__getpwuid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getpwuid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getpwuid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t e = 0;
@@ -384,7 +384,7 @@ int32_t SPVM__Sys__User__getpwnam(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getpwnam is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getpwnam is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t e = 0;
@@ -392,7 +392,7 @@ int32_t SPVM__Sys__User__getpwnam(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_pwnam = stack[0].oval;
   
   if (!obj_pwnam) {
-    return env->die(env, stack, "The user name must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $pwnam must be defined", FILE_NAME, __LINE__);
   }
   const char* pwnam = env->get_chars(env, stack, obj_pwnam);
   
@@ -422,7 +422,7 @@ int32_t SPVM__Sys__User__getgrgid(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getgrgid is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getgrgid is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t e = 0;
@@ -455,7 +455,7 @@ int32_t SPVM__Sys__User__getgrnam(SPVM_ENV* env, SPVM_VALUE* stack) {
   (void)stack;
   
 #ifdef _WIN32
-  env->die(env, stack, "getgrnam is not supported on this system", FILE_NAME, __LINE__);
+  env->die(env, stack, "getgrnam is not supported on this system(_WIN32)", FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED;
 #else
   int32_t e = 0;
@@ -463,7 +463,7 @@ int32_t SPVM__Sys__User__getgrnam(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_grnam = stack[0].oval;
   
   if (!obj_grnam) {
-    return env->die(env, stack, "The group name must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The $grnam must be defined", FILE_NAME, __LINE__);
   }
   const char* grnam = env->get_chars(env, stack, obj_grnam);
   
